JkTabs class

Inheritance

Constructors

JkTabs({Key? key, required List<JkTabsItem> items, required int currentIndex, required ValueChanged<int> onChanged, JkTabsVariant variant = JkTabsVariant.line, EdgeInsetsGeometry? padding, Color? backgroundColor, Color? activeColor, Color? inactiveColor, bool scrollable = false, double tabSpacing = 8, double indicatorWidth = 22, double indicatorHeight = 3, Color? indicatorColor, Duration duration = const Duration(milliseconds: 220), double itemHeight = 40, EdgeInsetsGeometry itemPadding = const EdgeInsets.symmetric(horizontal: 10), TextStyle? activeTextStyle, TextStyle? inactiveTextStyle, bool alignLeft = false, bool autoScrollToCenter = true, double indicatorGap = 4})
const

Properties

activeColor Color?
final
activeTextStyle TextStyle?
final
alignLeft bool
final
autoScrollToCenter bool
final
backgroundColor Color?
final
currentIndex int
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
inactiveColor Color?
final
inactiveTextStyle TextStyle?
final
indicatorColor Color?
final
indicatorGap double
final
indicatorHeight double
final
indicatorWidth double
final
itemHeight double
final
itemPadding EdgeInsetsGeometry
final
items List<JkTabsItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<int>
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollable bool
final
tabSpacing double
final
variant JkTabsVariant
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<JkTabs>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited