JkTimeAxisLayout enum

时间与主内容的左右关系(对齐 FirstUI TimeAxis 常见排布)。

Inheritance
Available extensions

Values

contentOnRight → const JkTimeAxisLayout

时间在左,轴线在中,主内容在右(默认)。

contentOnLeft → const JkTimeAxisLayout

主内容在左,轴线在中,时间在右。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<JkTimeAxisLayout>
A constant List of the values in this enum, in order of their declaration.